#!/usr/bin/env python3

# (c) Copyright [2020 - 2021] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (Micro Focus) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions
# contained herein. The information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items are licensed
# to the U.S. Government under vendor's standard commercial license.

import os
import json
import gettext
import fcntl
import subprocess
from time import strptime, mktime
from collections import OrderedDict

#Write the health of LUM service to /var/opt/novell/lum/lum.json
def writeJSON(dictionary):
	try:
		with open("/var/opt/novell/lum/lum.json", "w") as lumstatusfile:
			fcntl.flock(lumstatusfile, fcntl.LOCK_EX | fcntl.LOCK_NB)
			json.dump(dictionary, lumstatusfile, indent=4, separators=(", ", ": "))
			fcntl.flock(lumstatusfile, fcntl.LOCK_UN)
	except IOError:
		raise Exception("Failed to open/write the Json file /var/opt/novell/lum/lum.json")

#Get LUM Health status data
def genHealthStatus():
	lumsystemctl_cmd = "systemctl is-active namcd"
	lumstatus = subprocess.getoutput(lumsystemctl_cmd)
	jsonlum_stream = OrderedDict(
		[
			('serviceName', 'Linux User Management(LUM)'),
			('status', ''),
			('AdditionalInfo', ''),
			('children',
				[OrderedDict(
				[
					('serviceName', 'namcd'),
					('status', ''),
					('runningSince' , ''),
					('AdditionalInfo', ''),
					('children', None)
				]),
				OrderedDict(
				[
					('serviceName', 'LDAP Services for eDirectory'),
					('status', ''),
					('runningSince' , ''),
					('AdditionalInfo', ''),
					('children', None)
				])]
			)
		])
	ldap_daemon,ldapstatus_output = subprocess.getstatusoutput("/opt/novell/eDirectory/sbin/nldap.bin -s")
	ndsdsystemctl_cmd = "systemctl is-active ndsd"
	ndsdstatus = subprocess.getoutput(ndsdsystemctl_cmd)

	if(lumstatus == "inactive"):
		jsonlum_stream["children"][0]["status"] = ("UnHealthy")
		jsonlum_stream["children"][0]["runningSince"] = 0
		jsonlum_stream["children"][0]["AdditionalInfo"] = ["namcd service","Common_Inactive","Common_ResolveService"]
	else:
		lumtimestamp_cmd = "systemctl show -p ExecMainStartTimestamp namcd"
		lumtimestatus = subprocess.getoutput(lumtimestamp_cmd)
		timestamp_output = lumtimestatus.strip().split("=")
		target_timestamp = strptime(timestamp_output[1], '%a %Y-%m-%d %H:%M:%S %Z')
		epoch_time = mktime(target_timestamp)
		jsonlum_stream["children"][0]["status"] = ("Healthy")
		jsonlum_stream["children"][0]["runningSince"] = int(epoch_time)

	if (ldap_daemon == 0):
		jsonlum_stream["children"][1]["status"] = ("Healthy")
		if(ndsdstatus == "active"):
			ndsdtimestamp_cmd = "systemctl show -p ExecMainStartTimestamp ndsd"
			ndsdtimestatus = subprocess.getoutput(ndsdtimestamp_cmd)
			ndsdtimestamp_output = ndsdtimestatus.strip().split("=")
			ndsdtarget_timestamp = strptime(ndsdtimestamp_output[1], '%a %Y-%m-%d %H:%M:%S %Z')
			ndsdepoch_time = mktime(ndsdtarget_timestamp)
			jsonlum_stream["children"][1]["runningSince"] = int(ndsdepoch_time)
		else:
			jsonlum_stream["children"][1]["runningSince"] = 0
	else:
		jsonlum_stream["children"][1]["status"] = ("UnHealthy")
		jsonlum_stream["children"][1]["runningSince"] = 0
		jsonlum_stream["children"][1]["AdditionalInfo"] = ["LDAP Services for eDirectory","Common_Inactives","Common_ResolveServices"]

	if ((jsonlum_stream["children"][0]["status"] == "Healthy") and (jsonlum_stream["children"][1]["status"] == "Healthy")):
		jsonlum_stream["status"] = ("Healthy")
	else:
		jsonlum_stream["status"] = ("UnHealthy")
		jsonlum_stream["AdditionalInfo"] = ["Common_DependentService","LUM","Common_Inactives","Common_ResolveServices"]
	return jsonlum_stream

healthData = genHealthStatus()

try:
	writeJSON(healthData)
except Exception:
        exit(1)

